Branch: master

3c9e39e2 2015-09-18 14:57:02 Timothy Pearson
Fix prior commit
M tdecore/tdehw/tdestoragedevice.cpp
diff --git a/tdecore/tdehw/tdestoragedevice.cpp b/tdecore/tdehw/tdestoragedevice.cpp
index ff309f0..87ee036 100644
--- a/tdecore/tdehw/tdestoragedevice.cpp
+++ b/tdecore/tdehw/tdestoragedevice.cpp
@@ -146,7 +146,7 @@
 					ret = crypt_load(m_cryptDevice, NULL, NULL);
 					if (ret == 0) {
 						int keyslot_count;
-#ifdef CRYPTSETUP_OLD_API
+#if defined(CRYPTSETUP_OLD_API) || defined(HAVE_CRYPTSETUP_GET_TYPE)
 						kdWarning() << "TDEStorageDevice: The version of libcryptsetup that TDE was compiled against was too old!  Most LUKS features will not function" << endl;
 						m_cryptDeviceType = TQString::null;
 						keyslot_count = 0;
e38596f9 2015-09-18 14:57:11 Timothy Pearson
When reactivating card watching, if a card is inserted re-emit valid certificates to client application
M tdecore/tdehw/tdecryptographiccarddevice.cpp
diff --git a/tdecore/tdehw/tdecryptographiccarddevice.cpp b/tdecore/tdehw/tdecryptographiccarddevice.cpp
index 0125c39..dd3c778 100644
--- a/tdecore/tdehw/tdecryptographiccarddevice.cpp
+++ b/tdecore/tdehw/tdecryptographiccarddevice.cpp
@@ -459,7 +459,13 @@
 #ifdef WITH_PCSC
 	if (enable) {
 		if (m_watcherObject && m_watcherThread) {
-			// Monitoring thread already active; abort!
+			// Monitoring thread already active
+			if ((cardPresent() == 1) && (cardX509Certificates().count() > 0)) {
+				// Card was already inserted and initialized
+				emit(certificateListAvailable(this));
+			}
+
+			// Abort!
 			return;
 		}